#!/bin/sh
# This script can be used to create a MDM package for Silverback based on an PKG

# This method prints the help for the this script
printHelp() 
{
    help="${YELLOW}
	Help description:\n

    This script can be used to build the manifest.plist to distribute this package using Silverback or some other MDM solution.\n
    This script requires the following paramaters:\n\n
  
    -p Path to package\n
    -n The display name of the package (It must not be the same like the pkg name)\n
    -v The version of the package\n
    -i The bundle identifier of the package\n${NOCOLOR}
    "
    echo $help
}
CurrentPath=""
PathToPackage=""
PackageUrl="https://"
PackageName=""
Version=""
BundleIdentifier=""
RED='\033[0;31m'
GREEN='\033[0;32m'
NOCOLOR='\033[0m'
YELLOW='\033[1;33m'

# Parse commandline parameters
while getopts p:n:v:i:c: option
do
case "${option}"
in
p) PathToPackage=${OPTARG};;
n) PackageName=${OPTARG};;
v) Version=${OPTARG};;
i) BundleIdentifier=${OPTARG};;
c) CurrentPath=${OPTARG};;
esac
done


# Check if one of the parameters is missing 
if [ "$PathToPackage" = "" ] || [ "$PackageUrl" = "" ] || [ "$PackageName" = "" ] || [ "$Version" = "" ] || [ "$BundleIdentifier" = "" ]
then
    echo "${RED}\n################################################################################
##################### ERROR: At least one argument is missing ##################
################################################################################\n${NOCOLOR}"
    printHelp
    exit -1
fi

# Print usage 
echo "${YELLOW}\n################################################################################
############################### Use parameters ##################################
################################################################################\n${NOCOLOR}"

echo "Path to package: $PathToPackage"
echo "Packagename: $PackageName"
echo "Packageversion: $Version"
echo "Bundleidentifier of the package: $BundleIdentifier"
echo "CurrentPath: $CurrentPath"
# Prepare Directory 
WorkingDirectory=$(dirname "${PathToPackage}")
echo "Working directory: $WorkingDirectory"

# Start scirpt
echo "${YELLOW}\n################################################################################
############################### Start script ###################################
################################################################################\n${NOCOLOR}"

# Start scirpt
echo "${YELLOW}\n################################################################################
############################# Create manifest.plist ############################
################################################################################${NOCOLOR}"
echo "....."
# Create manifest

"$CurrentPath"/appmanifest "$PathToPackage" > "$WorkingDirectory/manifest.plist"

# Start scirpt
echo "${YELLOW}\n################################################################################
################################## Set metadata ################################
################################################################################${NOCOLOR}"
echo "....."

FileSize=$(stat -f%z "$PathToPackage")
# Set metadata
/usr/libexec/PlistBuddy -c "Add :items:0:metadata dict" "$WorkingDirectory/manifest.plist"
/usr/libexec/PlistBuddy -c "Add :items:0:metadata:sizeInBytes string $FileSize" "$WorkingDirectory/manifest.plist"
/usr/libexec/PlistBuddy -c "Add :items:0:metadata:bundle-identifier string $BundleIdentifier" "$WorkingDirectory/manifest.plist"
/usr/libexec/PlistBuddy -c "Add :items:0:metadata:bundle-version string $Version" "$WorkingDirectory/manifest.plist"
/usr/libexec/PlistBuddy -c "Add :items:0:metadata:kind string software" "$WorkingDirectory/manifest.plist"
/usr/libexec/PlistBuddy -c "Add :items:0:metadata:subtitle string " "$WorkingDirectory/manifest.plist"
/usr/libexec/PlistBuddy -c "Add :items:0:metadata:title string $PackageName" "$WorkingDirectory/manifest.plist"
/usr/libexec/PlistBuddy -c "Set :items:0:assets:0:url $PackageUrl" "$WorkingDirectory/manifest.plist"


echo "${GREEN}\n################################################################################
########################## SUCCESS: Finished creation ##########################
################################################################################\n${NOCOLOR}"





